@@ -7,7 +7,7 @@ use warnings;
 use JSON;
 use Slack::RTM::Bot::Client;
 
-our $VERSION = "0.11";
+our $VERSION = "0.12";
 
 pipe(READH, WRITEH);
 select(WRITEH);$|=1;
@@ -96,7 +96,7 @@ sub say {
 					subtype => 'bot_message',
 					bot_id  => $self->{client}->{info}->{self}->{id},
 					%$args,
-					channel => $self->{client}->{info}->_find_channel_id($args->{channel}),
+					channel => $self->{client}->{info}->_find_channel_or_group_id($args->{channel}),
 			}) . "\n";
 }
 
